'use strict';

// eslint-disable-next-line func-names
(function ($) {
  var allowAction = $.rails.allowAction;

  var origAllowAction = allowAction.bind($.rails);

  // NOTE: HTML5のvalidation でエラーのある場合に confirm ダイアログを表示するとネイティブのエラーメッセージが表示されない
  // https://github.com/rails/jquery-ujs/blob/3bff9e049afcb38191c6eb470062b9e51f46e535/src/rails.js#L294
  // eslint-disable-next-line no-param-reassign
  $.rails.allowAction = function (element) {
    var form = element.closest('form').get(0);
    if (form && form.checkValidity && !form.checkValidity()) {
      return true;
    }

    return origAllowAction(element);
  };

  // NOTE: remote: true でファイルアップロードも有効に
  var handleRemote = function handleRemote(form) {
    var formData = new FormData(form);
    // NOTE: IEのバグ対策
    // https://blog.yorkxin.org/2014/02/06/ajax-with-formdata-is-broken-on-ie10-ie11
    formData.append('_file_upload', 1);

    // NOTE: jquery-ujs で13ミリ秒後に無効→有効となった後に再度無効化
    // https://github.com/rails/jquery-ujs/blob/3bff9e049afcb38191c6eb470062b9e51f46e535/src/rails.js#L507
    setTimeout(function () {
      $.rails.disableFormElements($(form));
    }, 20);

    $.ajax({
      type: form.method || 'POST',
      url: form.action,
      data: formData,
      processData: false,
      contentType: false
    }).done(function () {
      for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      $(form).trigger('ajax:success', args);
    }).fail(function () {
      for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
        args[_key2] = arguments[_key2];
      }

      $(form).trigger('ajax:error', args);
    }).always(function () {
      for (var _len3 = arguments.length, args = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
        args[_key3] = arguments[_key3];
      }

      $(form).trigger('ajax:complete', args);
    });
  };

  $(document).on('ajax:aborted:file', 'form', function (_ref) {
    var currentTarget = _ref.currentTarget;

    handleRemote(currentTarget);
    return false;
  });
})(jQuery);